summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ANNOUNCE8
-rw-r--r--CHANGES2
-rw-r--r--CMakeLists.txt12
-rw-r--r--LICENSE4
-rw-r--r--README2
-rw-r--r--contrib/libtests/pngimage.c4
-rw-r--r--contrib/libtests/pngunknown.c2
-rw-r--r--libpng-manual.txt4
-rw-r--r--libpng.312
-rw-r--r--libpngpf.32
-rw-r--r--png.52
-rw-r--r--png.c4
-rw-r--r--png.h10
-rw-r--r--pngconf.h2
-rw-r--r--projects/vstudio/README.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt2
-rw-r--r--scripts/pnglibconf.h.prebuilt2
18 files changed, 39 insertions, 39 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 8c5f382ec..387d08147 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,4 +1,4 @@
-Libpng 1.6.22beta02 - January 30, 2016
+Libpng 1.6.22beta02 - February 8, 2016
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -14,8 +14,8 @@ Source files with LF line endings (for Unix/Linux) and with a
Source files with CRLF line endings (for Windows), without the
"configure" script
- /scratch/glennrp/Libpng16/lp1622b02.7z (LZMA-compressed, recommended)
- /scratch/glennrp/Libpng16/lp1622b02.zip
+ lp1622b02.7z (LZMA-compressed, recommended)
+ lp1622b02.zip
Other information:
@@ -40,7 +40,7 @@ Version 1.6.22beta01 [January 23, 2016]
less than 4GByte and image row size (stride) to less than 2GByte.
Revised workaround for false-positive Coverity issue in pngvalid.c.
-Version 1.6.22beta02 [January 30, 2016]
+Version 1.6.22beta02 [February 8, 2016]
Only use exit(77) in configure builds.
Corrected error in PNG_IMAGE_PNG_SIZE_MAX. This new macro underreported
the palette size because it failed to take into account that the memory
diff --git a/CHANGES b/CHANGES
index 3315e88a1..fb83fa805 100644
--- a/CHANGES
+++ b/CHANGES
@@ -5499,7 +5499,7 @@ Version 1.6.22beta01 [January 23, 2016]
less than 4GByte and image row size (stride) to less than 2GByte.
Revised workaround for false-positive Coverity issue in pngvalid.c.
-Version 1.6.22beta02 [January 30, 2016]
+Version 1.6.22beta02 [February 8, 2016]
Only use exit(77) in configure builds.
Corrected error in PNG_IMAGE_PNG_SIZE_MAX. This new macro underreported
the palette size because it failed to take into account that the memory
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 0b60ce035..1a96b6a69 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -528,11 +528,11 @@ if(PNG_TESTS AND PNG_SHARED)
COMMAND pngvalid OPTIONS --gamma-alpha-mode)
png_add_test(NAME pngvalid-gamma-background
COMMAND pngvalid OPTIONS --gamma-background)
- png_add_test(NAME pngvalid-gamma-alpha-mode-expand16
+ png_add_test(NAME pngvalid-gamma-expand16-alpha-mode
COMMAND pngvalid OPTIONS --gamma-alpha-mode --expand16)
- png_add_test(NAME pngvalid-gamma-background-expand16
+ png_add_test(NAME pngvalid-gamma-expand16-background
COMMAND pngvalid OPTIONS --gamma-background --expand16)
- png_add_test(NAME pngvalid-gamma-transform-expand16
+ png_add_test(NAME pngvalid-gamma-expand16-transform
COMMAND pngvalid OPTIONS --gamma-transform --expand16)
png_add_test(NAME pngvalid-gamma-sbit
COMMAND pngvalid OPTIONS --gamma-sbit)
@@ -540,11 +540,11 @@ if(PNG_TESTS AND PNG_SHARED)
COMMAND pngvalid OPTIONS --gamma-threshold)
png_add_test(NAME pngvalid-gamma-transform
COMMAND pngvalid OPTIONS --gamma-transform)
- png_add_test(NAME pngvalid-standard-progressive-read-interlace
+ png_add_test(NAME pngvalid-progressive-interlace-standard
COMMAND pngvalid OPTIONS --standard --progressive-read --interlace)
- png_add_test(NAME pngvalid-size-progressive-read
+ png_add_test(NAME pngvalid-progressive-size
COMMAND pngvalid OPTIONS --size --progressive-read)
- png_add_test(NAME pngvalid-standard-progressive-read
+ png_add_test(NAME pngvalid-progressive-standard
COMMAND pngvalid OPTIONS --standard --progressive-read)
png_add_test(NAME pngvalid-standard
COMMAND pngvalid OPTIONS --standard)
diff --git a/LICENSE b/LICENSE
index 83e88035b..20e8dd219 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000, through 1.6.22beta02, January 23, 2016, are
+libpng versions 1.0.7, July 1, 2000, through 1.6.22beta02, February 8, 2016, are
Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
derived from libpng-1.0.6, and are distributed according to the same
disclaimer and license as libpng-1.0.6 with the following individuals
@@ -109,4 +109,4 @@ the additional disclaimers inserted at version 1.0.7.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-January 23, 2016
+February 8, 2016
diff --git a/README b/README
index d92c2f460..3ad0b5f3e 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.6.22beta02 - January 23, 2016 (shared library 16.0)
+README for libpng version 1.6.22beta02 - February 8, 2016 (shared library 16.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/contrib/libtests/pngimage.c b/contrib/libtests/pngimage.c
index c44dd77cb..641357316 100644
--- a/contrib/libtests/pngimage.c
+++ b/contrib/libtests/pngimage.c
@@ -1,8 +1,8 @@
/* pngimage.c
*
- * Copyright (c) 2015 John Cunningham Bowler
+ * Copyright (c) 2015,2016 John Cunningham Bowler
*
- * Last changed in libpng 1.6.20 [December 3, 2015]
+ * Last changed in libpng 1.6.22 [(PENDING RELEASE)]
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
diff --git a/contrib/libtests/pngunknown.c b/contrib/libtests/pngunknown.c
index 915033ea8..b5ab04a41 100644
--- a/contrib/libtests/pngunknown.c
+++ b/contrib/libtests/pngunknown.c
@@ -2,7 +2,7 @@
/* pngunknown.c - test the read side unknown chunk handling
*
* Last changed in libpng 1.6.22 [(PENDING RELEASE)]
- * Copyright (c) 2016 Glenn Randers-Pehrson
+ * Copyright (c) 2015,2016 Glenn Randers-Pehrson
* Written by John Cunningham Bowler
*
* This code is released under the libpng license.
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 97007ad10..749df379b 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.22beta02 - January 30, 2016
+ libpng version 1.6.22beta02 - February 8, 2016
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2016 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.22beta02 - January 30, 2016
+ libpng versions 0.97, January 1998, through 1.6.22beta02 - February 8, 2016
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2016 Glenn Randers-Pehrson
diff --git a/libpng.3 b/libpng.3
index b3d044378..0d98c10b4 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "January 30, 2016"
+.TH LIBPNG 3 "February 8, 2016"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.6.22beta02
.SH SYNOPSIS
@@ -510,7 +510,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.22beta02 - January 30, 2016
+ libpng version 1.6.22beta02 - February 8, 2016
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2016 Glenn Randers-Pehrson
@@ -521,7 +521,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.22beta02 - January 30, 2016
+ libpng versions 0.97, January 1998, through 1.6.22beta02 - February 8, 2016
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2016 Glenn Randers-Pehrson
@@ -6005,7 +6005,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.6.22beta02 - January 30, 2016:
+Libpng version 1.6.22beta02 - February 8, 2016:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -6030,7 +6030,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000, through 1.6.22beta02, January 30, 2016, are
+libpng versions 1.0.7, July 1, 2000, through 1.6.22beta02, February 8, 2016, are
Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
derived from libpng-1.0.6, and are distributed according to the same
disclaimer and license as libpng-1.0.6 with the following individuals
@@ -6129,7 +6129,7 @@ the additional disclaimers inserted at version 1.0.7.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-January 30, 2016
+February 8, 2016
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index a95bec499..050ddedf4 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "January 23, 2016"
+.TH LIBPNGPF 3 "February 8, 2016"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.6.22beta02
(private functions)
diff --git a/png.5 b/png.5
index 6fa504e64..f1e6c3a0d 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "January 23, 2016"
+.TH PNG 5 "February 8, 2016"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 690382496..7d2da1a32 100644
--- a/png.c
+++ b/png.c
@@ -775,14 +775,14 @@ png_get_copyright(png_const_structrp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.6.22beta02 - January 23, 2016" PNG_STRING_NEWLINE \
+ "libpng version 1.6.22beta02 - February 8, 2016" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson" \
PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.6.22beta02 - January 23, 2016\
+ return "libpng version 1.6.22beta02 - February 8, 2016\
Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 87d8605c9..3cf511e55 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.6.22beta02, January 23, 2016
+ * libpng version 1.6.22beta02, February 8, 2016
*
* Copyright (c) 1998-2002,2004,2006-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/projects/vstudio/README.txt b/projects/vstudio/README.txt
index 22c53a74c..2c358bc26 100644
--- a/projects/vstudio/README.txt
+++ b/projects/vstudio/README.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.6.22beta02 - January 23, 2016
+libpng version 1.6.22beta02 - February 8, 2016
Copyright (c) 2010,2013,2015 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 6e05fea18..70dea92e3 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.6.22beta02 - January 23, 2016
+ * libpng version 1.6.22beta02 - February 8, 2016
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 8ed4ebb9c..1302bfe9c 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
-Makefiles for libpng version 1.6.22beta02 - January 23, 2016
+Makefiles for libpng version 1.6.22beta02 - February 8, 2016
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 1fb1f546d..a1deb3db7 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -2,7 +2,7 @@
/* pnglibconf.h - library build configuration */
-/* Libpng version 1.6.22beta02 - January 23, 2016 */
+/* Libpng version 1.6.22beta02 - February 8, 2016 */
/* Copyright (c) 1998-2015 Glenn Randers-Pehrson */
diff --git a/png.h b/png.h
index 23d76bc60..b5f6aaf3f 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.22beta02, January 23, 2016
*
* Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.22beta02, January 23, 2016:
* Glenn Randers-Pehrson.
* See also "Contributing Authors", below.
*/
@@ -25,7 +25,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.0.7, July 1, 2000, through 1.6.22beta02, January 23, 2016, are
* Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same
* disclaimer and license as libpng-1.0.6 with the following individuals
@@ -214,7 +214,7 @@
* Y2K compliance in libpng:
* =========================
*
- * January 23, 2016
+ * February 8, 2016
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -284,7 +284,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.6.22beta02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.22beta02 - January 23, 2016\n"
+ " libpng version 1.6.22beta02 - February 8, 2016\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.22beta02, January 23, 2016
+ * libpng version 1.6.22beta02, February 8, 2016
*
* Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.22beta02, January 23, 2016:
+ * libpng versions 0.97, January 1998, through 1.6.22beta02, February 8, 2016:
* Glenn Randers-Pehrson.
* See also "Contributing Authors", below.
@@ -25,7 +25,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.0.7, July 1, 2000, through 1.6.22beta02, January 23, 2016, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.6.22beta02, February 8, 2016, are
* Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same